==> lndb_hub-0.5.0.tar.gz: lndb_hub-0.5.0/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
Enforce compatibility with hub schema | [11](https://github.com/laminlabs/lndb-hub/pull/11) | [fredericenard](https://github.com/fredericenard) | 2022-08-22 | 0.5.0
⬆️ Upgrade hub schema (core schema v0.3.4) | [10](https://github.com/laminlabs/lndb-hub/pull/10) | [fredericenard](https://github.com/fredericenard) | 2022-08-22 |
⚠️ Add consistency check for user db schema and hub schema | [7](https://github.com/laminlabs/lndb-hub/pull/7) | [fredericenard](https://github.com/fredericenard) | 2022-08-19 | 0.4.0
🐛 Fix load import | [6](https://github.com/laminlabs/lndb-hub/pull/6) | [falexwolf](https://github.com/falexwolf) | 2022-08-02 | 0.3.2
🐛 Except delete `jupynb` | [5](https://github.com/laminlabs/lndb-hub/pull/5) | [falexwolf](https://github.com/falexwolf) | 2022-08-02 | 0.3.1
⬆️ Upgrade to `lndb_setup` 0.4.0 | [4](https://github.com/laminlabs/lndb-hub/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-08-01 | 0.3.0
🚚 Rename `load` to `load.entity` | [3](https://github.com/laminlabs/lndb-hub/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-01 | 0.2.1
⬆️ Upgrade to `lndb_schema_core` 0.2.0 | [2](https://github.com/laminlabs/lndb-hub/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.2.0
🚚 Move the code from `lamindb` here | [1](https://github.com/laminlabs/lndb-hub/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.1.0

==> lndb_hub-0.5.2.tar.gz: lndb_hub-0.5.2/docs/changelog.md <==
# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
Enforce schema compatibility. | [16](https://github.com/laminlabs/lndb-hub/pull/16) | [fredericenard](https://github.com/fredericenard) | 2022-08-27 | 0.5.2
Track usage. | [14](https://github.com/laminlabs/lndb-hub/pull/14) | [fredericenard](https://github.com/fredericenard) | 2022-08-25 |
Use id to reference storage | [13](https://github.com/laminlabs/lndb-hub/pull/13) | [fredericenard](https://github.com/fredericenard) | 2022-08-23 | 0.5.1
Enforce compatibility with hub schema | [11](https://github.com/laminlabs/lndb-hub/pull/11) | [fredericenard](https://github.com/fredericenard) | 2022-08-22 | 0.5.0
⬆️ Upgrade hub schema (core schema v0.3.4) | [10](https://github.com/laminlabs/lndb-hub/pull/10) | [fredericenard](https://github.com/fredericenard) | 2022-08-22 |
⚠️ Add consistency check for user db schema and hub schema | [7](https://github.com/laminlabs/lndb-hub/pull/7) | [fredericenard](https://github.com/fredericenard) | 2022-08-19 | 0.4.0
🐛 Fix load import | [6](https://github.com/laminlabs/lndb-hub/pull/6) | [falexwolf](https://github.com/falexwolf) | 2022-08-02 | 0.3.2
🐛 Except delete `jupynb` | [5](https://github.com/laminlabs/lndb-hub/pull/5) | [falexwolf](https://github.com/falexwolf) | 2022-08-02 | 0.3.1
⬆️ Upgrade to `lndb_setup` 0.4.0 | [4](https://github.com/laminlabs/lndb-hub/pull/4) | [falexwolf](https://github.com/falexwolf) | 2022-08-01 | 0.3.0
🚚 Rename `load` to `load.entity` | [3](https://github.com/laminlabs/lndb-hub/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2022-08-01 | 0.2.1
⬆️ Upgrade to `lndb_schema_core` 0.2.0 | [2](https://github.com/laminlabs/lndb-hub/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.2.0
🚚 Move the code from `lamindb` here | [1](https://github.com/laminlabs/lndb-hub/pull/1) | [falexwolf](https://github.com/falexwolf) | 2022-07-29 | 0.1.0
